# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['blendmodes']

package_data = \
{'': ['*']}

install_requires = \
['Deprecated>=1.2.12,<2',
 'Pillow>=8.2.0,<9',
 'aenum>=3.1.0,<4',
 'numpy>=1.20.3,<2']

setup_kwargs = {
    'name': 'blendmodes',
    'version': '2021.3.1',
    'description': 'Use this module to apply a number of blending modes to a background and foreground image',
    'long_description': '[![GitHub top language](https://img.shields.io/github/languages/top/FHPythonUtils/BlendModes.svg?style=for-the-badge)](../../)\n[![Repository size](https://img.shields.io/github/repo-size/FHPythonUtils/BlendModes.svg?style=for-the-badge)](../../)\n[![Issues](https://img.shields.io/github/issues/FHPythonUtils/BlendModes.svg?style=for-the-badge)](../../issues)\n[![License](https://img.shields.io/github/license/FHPythonUtils/BlendModes.svg?style=for-the-badge)](/LICENSE.md)\n[![Commit activity](https://img.shields.io/github/commit-activity/m/FHPythonUtils/BlendModes.svg?style=for-the-badge)](../../commits/master)\n[![Last commit](https://img.shields.io/github/last-commit/FHPythonUtils/BlendModes.svg?style=for-the-badge)](../../commits/master)\n[![PyPI Downloads](https://img.shields.io/pypi/dm/blendmodes.svg?style=for-the-badge)](https://pypistats.org/packages/blendmodes)\n[![PyPI Total Downloads](https://img.shields.io/badge/dynamic/json?style=for-the-badge&label=total%20downloads&query=%24.total_downloads&url=https%3A%2F%2Fapi.pepy.tech%2Fapi%2Fprojects%2Fblendmodes)](https://pepy.tech/project/blendmodes)\n[![PyPI Version](https://img.shields.io/pypi/v/blendmodes.svg?style=for-the-badge)](https://pypi.org/project/blendmodes)\n\n<!-- omit in TOC -->\n# BlendModes\n\n<img src="readme-assets/icons/name.png" alt="Project Icon" width="750">\n\nUse this module to apply a number of blending modes to a background and\nforeground image.\n\n## Credits\n\nCredits to:\n\n### MIT License Copyright (c) 2019 Paul Jewell\nFor implementing blending from the Open Raster Image Spec\n\n### MIT License Copyright (c) 2018 Addison Elliott\nFor implementing blending from Paint.NET\n\n### MIT License Copyright (c) 2017 pashango\nFor implementing a number of blending functions used by other popular image\neditors\n\n- [Credits](#credits)\n\t- [MIT License Copyright (c) 2019 Paul Jewell](#mit-license-copyright-c-2019-paul-jewell)\n\t- [MIT License Copyright (c) 2018 Addison Elliott](#mit-license-copyright-c-2018-addison-elliott)\n\t- [MIT License Copyright (c) 2017 pashango](#mit-license-copyright-c-2017-pashango)\n- [Examples](#examples)\n\t- [Normal](#normal)\n\t- [Multiply](#multiply)\n\t- [Additive](#additive)\n\t- [ColourBurn](#colourburn)\n\t- [ColourDodge](#colourdodge)\n\t- [Reflect](#reflect)\n\t- [Glow](#glow)\n\t- [Overlay](#overlay)\n\t- [Difference](#difference)\n\t- [Negation](#negation)\n\t- [Lighten](#lighten)\n\t- [Darken](#darken)\n\t- [Screen](#screen)\n\t- [XOR](#xor)\n\t- [SoftLight](#softlight)\n\t- [HardLight](#hardlight)\n\t- [GrainExtract](#grainextract)\n\t- [GrainMerge](#grainmerge)\n\t- [Divide](#divide)\n\t- [Hue](#hue)\n\t- [Saturation](#saturation)\n\t- [Colour](#colour)\n\t- [Luminosity](#luminosity)\n\t- [PinLight](#pinlight)\n\t- [VividLight](#vividlight)\n\t- [Exclusion](#exclusion)\n\t- [DestIn](#destin)\n\t- [DestOut](#destout)\n\t- [DestAtop](#destatop)\n\t- [SrcAtop](#srcatop)\n- [Documentation](#documentation)\n- [Install With PIP](#install-with-pip)\n- [Language information](#language-information)\n\t- [Built for](#built-for)\n- [Install Python on Windows](#install-python-on-windows)\n\t- [Chocolatey](#chocolatey)\n\t- [Windows - Python.org](#windows---pythonorg)\n- [Install Python on Linux](#install-python-on-linux)\n\t- [Apt](#apt)\n\t- [Dnf](#dnf)\n- [Install Python on MacOS](#install-python-on-macos)\n\t- [Homebrew](#homebrew)\n\t- [MacOS - Python.org](#macos---pythonorg)\n- [How to run](#how-to-run)\n\t- [Windows](#windows)\n\t- [Linux/ MacOS](#linux-macos)\n- [Download Project](#download-project)\n\t- [Clone](#clone)\n\t\t- [Using The Command Line](#using-the-command-line)\n\t\t- [Using GitHub Desktop](#using-github-desktop)\n\t- [Download Zip File](#download-zip-file)\n- [Community Files](#community-files)\n\t- [Licence](#licence)\n\t- [Changelog](#changelog)\n\t- [Code of Conduct](#code-of-conduct)\n\t- [Contributing](#contributing)\n\t- [Security](#security)\n\t- [Support](#support)\n\t- [Rationale](#rationale)\n\n## Examples\n\nBe sure to include the following for the functions below\n\n```python\nfrom blendmodes.blend import blendLayers, BlendType\n\nbackground = Image.open(THISDIR + "/background.png")\nforeground = Image.open(THISDIR + "/foreground.png")\n```\n\n### Normal\n\n```python\nblendLayers(background, foreground, BlendType.NORMAL)\n```\n\n![Normal](test/normal_expected.png)\n\n### Multiply\n\n```python\nblendLayers(background, foreground, BlendType.MULTIPLY)\n```\n\n![Multiply](test/multiply_expected.png)\n\n### Additive\n\n```python\nblendLayers(background, foreground, BlendType.ADDITIVE)\n```\n\n![Additive](test/additive_expected.png)\n\n### ColourBurn\n\n```python\nblendLayers(background, foreground, BlendType.COLOURBURN)\n```\n\n![ColourBurn](test/colourburn_expected.png)\n\n### ColourDodge\n\n```python\nblendLayers(background, foreground, BlendType.COLOURDODGE)\n```\n\n![ColourDodge](test/colourdodge_expected.png)\n\n### Reflect\n\n```python\nblendLayers(background, foreground, BlendType.REFLECT)\n```\n\n![Reflect](test/reflect_expected.png)\n\n### Glow\n\n```python\nblendLayers(background, foreground, BlendType.GLOW)\n```\n\n![Glow](test/glow_expected.png)\n\n### Overlay\n\n```python\nblendLayers(background, foreground, BlendType.OVERLAY)\n```\n\n![Overlay](test/overlay_expected.png)\n\n### Difference\n\n```python\nblendLayers(background, foreground, BlendType.DIFFERENCE)\n```\n\n![Difference](test/difference_expected.png)\n\n### Negation\n\n```python\nblendLayers(background, foreground, BlendType.NEGATION)\n```\n\n![Negation](test/negation_expected.png)\n\n### Lighten\n\n```python\nblendLayers(background, foreground, BlendType.LIGHTEN)\n```\n\n![Lighten](test/lighten_expected.png)\n\n### Darken\n\n```python\nblendLayers(background, foreground, BlendType.DARKEN)\n```\n\n![Darken](test/darken_expected.png)\n\n### Screen\n\n```python\nblendLayers(background, foreground, BlendType.SCREEN)\n```\n\n![Screen](test/screen_expected.png)\n\n### XOR\n\n```python\nblendLayers(background, foreground, BlendType.XOR)\n```\n\n![XOR](test/xor_expected.png)\n\n### SoftLight\n\n```python\nblendLayers(background, foreground, BlendType.SOFTLIGHT)\n```\n\n![SoftLight](test/softlight_expected.png)\n\n### HardLight\n\n```python\nblendLayers(background, foreground, BlendType.HARDLIGHT)\n```\n\n![HardLight](test/hardlight_expected.png)\n\n### GrainExtract\n\n```python\nblendLayers(background, foreground, BlendType.GRAINEXTRACT)\n```\n\n![GrainExtract](test/grainextract_expected.png)\n\n### GrainMerge\n\n```python\nblendLayers(background, foreground, BlendType.GRAINMERGE)\n```\n\n![GrainMerge](test/grainmerge_expected.png)\n\n### Divide\n\n```python\nblendLayers(background, foreground, BlendType.DIVIDE)\n```\n\n![Divide](test/divide_expected.png)\n\n### Hue\n\n```python\nblendLayers(background, foreground, BlendType.HUE)\n```\n\n![Hue](test/hue_expected.png)\n\n### Saturation\n\n```python\nblendLayers(background, foreground, BlendType.SATURATION)\n```\n\n![Saturation](test/saturation_expected.png)\n\n### Colour\n\n```python\nblendLayers(background, foreground, BlendType.COLOUR)\n```\n\n![Colour](test/colour_expected.png)\n\n### Luminosity\n\n```python\nblendLayers(background, foreground, BlendType.LUMINOSITY)\n```\n\n![Luminosity](test/luminosity_expected.png)\n\n### PinLight\n\n```python\nblendLayers(background, foreground, BlendType.PINLIGHT)\n```\n\n![PinLight](test/pinlight_expected.png)\n\n### VividLight\n\n```python\nblendLayers(background, foreground, BlendType.VIVIDLIGHT)\n```\n\n![VividLight](test/vividlight_expected.png)\n\n### Exclusion\n\n```python\nblendLayers(background, foreground, BlendType.EXCLUSION)\n```\n\n![Exclusion](test/exclusion_expected.png)\n\n### DestIn\n\n```python\nblendLayers(background, foreground, BlendType.DESTIN)\n```\n\n![Exclusion](test/destin_expected.png)\n\n### DestOut\n\n```python\nblendLayers(background, foreground, BlendType.DESTOUT)\n```\n\n![Exclusion](test/destout_expected.png)\n\n### DestAtop\n\n```python\nblendLayers(background, foreground, BlendType.DESTATOP)\n```\n\n![Exclusion](test/destatop_expected.png)\n\n### SrcAtop\n\n```python\nblendLayers(background, foreground, BlendType.SRCATOP)\n```\n\n![Exclusion](test/srcatop_expected.png)\n\n## Documentation\nSee the [Docs](/DOCS/) for more information.\n\n## Install With PIP\n\n```python\npip install blendmodes\n```\n\nHead to https://pypi.org/project/blendmodes/ for more info\n\n## Language information\n### Built for\nThis program has been written for Python versions 3.7 - 3.10 and has been tested with both 3.7 and 3.10\n\n## Install Python on Windows\n### Chocolatey\n\n```powershell\nchoco install python\n```\n\n### Windows - Python.org\nTo install Python, go to https://www.python.org/downloads/windows/ and download the latest\nversion.\n\n## Install Python on Linux\n### Apt\n\n```bash\nsudo apt install python3.x\n```\n\n### Dnf\n\n```bash\nsudo dnf install python3.x\n```\n\n## Install Python on MacOS\n### Homebrew\n\n```bash\nbrew install python@3.x\n```\n\n### MacOS - Python.org\nTo install Python, go to https://www.python.org/downloads/macos/ and download the latest\nversion.\n\n## How to run\n### Windows\n\n- Module\n\n\t`python -3.x -m [module]` or `[module]` (if module installs a script)\n\n- File\n\n\t`python -3.x [file]` or `./[file]`\n\n### Linux/ MacOS\n\n- Module\n\n\t`python3.x -m [module]` or `[module]` (if module installs a script)\n\n- File\n\n\t`python3.x [file]` or `./[file]`\n\n## Download Project\n\n### Clone\n#### Using The Command Line\n\n1. Press the Clone or download button in the top right\n2. Copy the URL (link)\n3. Open the command line and change directory to where you wish to\nclone to\n4. Type \'git clone\' followed by URL in step 2\n\n\t```bash\n\tgit clone https://github.com/FHPythonUtils/BlendModes\n\t```\n\nMore information can be found at\nhttps://help.github.com/en/articles/cloning-a-repository\n\n#### Using GitHub Desktop\n\n1. Press the Clone or download button in the top right\n2. Click open in desktop\n3. Choose the path for where you want and click Clone\n\nMore information can be found at\nhttps://help.github.com/en/desktop/contributing-to-projects/cloning-a-repository-from-github-to-github-desktop\n\n### Download Zip File\n\n1. Download this GitHub repository\n2. Extract the zip archive\n3. Copy/ move to the desired location\n\n## Community Files\n### Licence\nMIT License\n(See the [LICENSE](/LICENSE.md) for more information.)\n\n### Changelog\nSee the [Changelog](/CHANGELOG.md) for more information.\n\n### Code of Conduct\nOnline communities include people from many backgrounds. The *Project*\ncontributors are committed to providing a friendly, safe and welcoming\nenvironment for all. Please see the\n[Code of Conduct](https://github.com/FHPythonUtils/.github/blob/master/CODE_OF_CONDUCT.md)\n for more information.\n\n### Contributing\nContributions are welcome, please see the\n[Contributing Guidelines](https://github.com/FHPythonUtils/.github/blob/master/CONTRIBUTING.md)\nfor more information.\n\n### Security\nThank you for improving the security of the project, please see the\n[Security Policy](https://github.com/FHPythonUtils/.github/blob/master/SECURITY.md)\nfor more information.\n\n### Support\nThank you for using this project, I hope it is of use to you. Please be aware that\nthose involved with the project often do so for fun along with other commitments\n(such as work, family, etc). Please see the\n[Support Policy](https://github.com/FHPythonUtils/.github/blob/master/SUPPORT.md)\nfor more information.\n\n### Rationale\nThe rationale acts as a guide to various processes regarding projects such as\nthe versioning scheme and the programming styles used. Please see the\n[Rationale](https://github.com/FHPythonUtils/.github/blob/master/RATIONALE.md)\nfor more information.\n',
    'author': 'FredHappyface',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/FHPythonUtils/BlendModes',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
